# API Reference {: .no-toc }

Comprehensive reference for the library types, generated with `mkdocstrings`.

## DNI

::: spanish_nif.dni.DNI
    options:
      heading_level: 3

::: spanish_nif.dni.InvalidDNI
    options:
      heading_level: 3

## NIE

::: spanish_nif.nie.NIE
    options:
      heading_level: 3

::: spanish_nif.nie.InvalidNIE
    options:
      heading_level: 3

## NIF

::: spanish_nif.nif.NIF
    options:
      heading_level: 3

::: spanish_nif.nif.InvalidNIF
    options:
      heading_level: 3
